# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseInstanceArgs', 'DatabaseInstance']

@pulumi.input_type
class DatabaseInstanceArgs:
    def __init__(__self__, *,
                 node_type: pulumi.Input[_builtins.str],
                 backup_same_region: Optional[pulumi.Input[_builtins.bool]] = None,
                 backup_schedule_frequency: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_schedule_retention: Optional[pulumi.Input[_builtins.int]] = None,
                 disable_backup: Optional[pulumi.Input[_builtins.bool]] = None,
                 encryption_at_rest: Optional[pulumi.Input[_builtins.bool]] = None,
                 engine: Optional[pulumi.Input[_builtins.str]] = None,
                 init_settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 is_ha_cluster: Optional[pulumi.Input[_builtins.bool]] = None,
                 load_balancer: Optional[pulumi.Input['DatabaseInstanceLoadBalancerArgs']] = None,
                 logs_policy: Optional[pulumi.Input['DatabaseInstanceLogsPolicyArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo_version: Optional[pulumi.Input[_builtins.int]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]]] = None,
                 private_network: Optional[pulumi.Input['DatabaseInstancePrivateNetworkArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DatabaseInstance resource.
        :param pulumi.Input[_builtins.str] node_type: The type of Database Instance you want to create (e.g. `db-dev-s`).
               
               > **Important** Updates to `node_type` will upgrade the Database Instance to the desired `node_type` without any
               interruption.
               
               > **Important** Once your Database Instance reaches `disk_full` status, if you are using `lssd` storage, you should upgrade the `node_type`, and if you are using `bssd` storage, you should increase the volume size before making any other changes to your Database Instance.
        :param pulumi.Input[_builtins.bool] backup_same_region: Boolean to store logical backups in the same region as the database instance
        :param pulumi.Input[_builtins.int] backup_schedule_frequency: Backup schedule frequency in hours
        :param pulumi.Input[_builtins.int] backup_schedule_retention: Backup schedule retention in days
        :param pulumi.Input[_builtins.bool] disable_backup: Disable automated backup for the database instance
        :param pulumi.Input[_builtins.bool] encryption_at_rest: Enable or disable encryption at rest for the Database Instance.
        :param pulumi.Input[_builtins.str] engine: Database's engine version name (e.g., 'PostgreSQL-16', 'MySQL-8'). Changing this value triggers a blue/green upgrade using MajorUpgradeWorkflow with automatic endpoint migration
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] init_settings: Map of engine settings to be set at database initialisation.
        :param pulumi.Input[_builtins.bool] is_ha_cluster: Enable or disable high availability for the Database Instance.
               
               > **Important** Updates to `is_ha_cluster` will recreate the Database Instance.
        :param pulumi.Input['DatabaseInstanceLoadBalancerArgs'] load_balancer: List of Load Balancer endpoints of the Database Instance.
        :param pulumi.Input['DatabaseInstanceLogsPolicyArgs'] logs_policy: Logs policy configuration
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.str] password: Password for the first user of the Database Instance. Only one of `password` or `password_wo` should be specified.
        :param pulumi.Input[_builtins.str] password_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        :param pulumi.Input[_builtins.int] password_wo_version: The version of the write-only password. To update the `password_wo`, you must also update the `password_wo_version`.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]] private_ips: The private IPv4 address associated with the resource.
        :param pulumi.Input['DatabaseInstancePrivateNetworkArgs'] private_network: List of Private Networks endpoints of the Database Instance.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Database
               Instance is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Database Instance should be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] settings: Map of engine settings to be set on a running instance.
        :param pulumi.Input[_builtins.str] snapshot_id: The ID of an existing snapshot to restore or create the Database Instance from. Conflicts with the `engine` parameter and backup settings.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Database Instance.
        :param pulumi.Input[_builtins.str] user_name: Identifier for the first user of the Database Instance.
               
               > **Important** Updates to `user_name` will recreate the Database Instance.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size (in GB). Cannot be used when `volume_type` is set to `lssd`.
               
               > **Important** Once your Database Instance reaches `disk_full` status, you should increase the volume size before making any other change to your Database Instance.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data are stored (`lssd`, `sbs_5k` or `sbs_15k`).
        """
        pulumi.set(__self__, "node_type", node_type)
        if backup_same_region is not None:
            pulumi.set(__self__, "backup_same_region", backup_same_region)
        if backup_schedule_frequency is not None:
            pulumi.set(__self__, "backup_schedule_frequency", backup_schedule_frequency)
        if backup_schedule_retention is not None:
            pulumi.set(__self__, "backup_schedule_retention", backup_schedule_retention)
        if disable_backup is not None:
            pulumi.set(__self__, "disable_backup", disable_backup)
        if encryption_at_rest is not None:
            pulumi.set(__self__, "encryption_at_rest", encryption_at_rest)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if init_settings is not None:
            pulumi.set(__self__, "init_settings", init_settings)
        if is_ha_cluster is not None:
            pulumi.set(__self__, "is_ha_cluster", is_ha_cluster)
        if load_balancer is not None:
            pulumi.set(__self__, "load_balancer", load_balancer)
        if logs_policy is not None:
            pulumi.set(__self__, "logs_policy", logs_policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_wo is not None:
            pulumi.set(__self__, "password_wo", password_wo)
        if password_wo_version is not None:
            pulumi.set(__self__, "password_wo_version", password_wo_version)
        if private_ips is not None:
            pulumi.set(__self__, "private_ips", private_ips)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if volume_size_in_gb is not None:
            pulumi.set(__self__, "volume_size_in_gb", volume_size_in_gb)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of Database Instance you want to create (e.g. `db-dev-s`).

        > **Important** Updates to `node_type` will upgrade the Database Instance to the desired `node_type` without any
        interruption.

        > **Important** Once your Database Instance reaches `disk_full` status, if you are using `lssd` storage, you should upgrade the `node_type`, and if you are using `bssd` storage, you should increase the volume size before making any other changes to your Database Instance.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter(name="backupSameRegion")
    def backup_same_region(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean to store logical backups in the same region as the database instance
        """
        return pulumi.get(self, "backup_same_region")

    @backup_same_region.setter
    def backup_same_region(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "backup_same_region", value)

    @_builtins.property
    @pulumi.getter(name="backupScheduleFrequency")
    def backup_schedule_frequency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Backup schedule frequency in hours
        """
        return pulumi.get(self, "backup_schedule_frequency")

    @backup_schedule_frequency.setter
    def backup_schedule_frequency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_schedule_frequency", value)

    @_builtins.property
    @pulumi.getter(name="backupScheduleRetention")
    def backup_schedule_retention(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Backup schedule retention in days
        """
        return pulumi.get(self, "backup_schedule_retention")

    @backup_schedule_retention.setter
    def backup_schedule_retention(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_schedule_retention", value)

    @_builtins.property
    @pulumi.getter(name="disableBackup")
    def disable_backup(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable automated backup for the database instance
        """
        return pulumi.get(self, "disable_backup")

    @disable_backup.setter
    def disable_backup(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_backup", value)

    @_builtins.property
    @pulumi.getter(name="encryptionAtRest")
    def encryption_at_rest(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable encryption at rest for the Database Instance.
        """
        return pulumi.get(self, "encryption_at_rest")

    @encryption_at_rest.setter
    def encryption_at_rest(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "encryption_at_rest", value)

    @_builtins.property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Database's engine version name (e.g., 'PostgreSQL-16', 'MySQL-8'). Changing this value triggers a blue/green upgrade using MajorUpgradeWorkflow with automatic endpoint migration
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "engine", value)

    @_builtins.property
    @pulumi.getter(name="initSettings")
    def init_settings(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of engine settings to be set at database initialisation.
        """
        return pulumi.get(self, "init_settings")

    @init_settings.setter
    def init_settings(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "init_settings", value)

    @_builtins.property
    @pulumi.getter(name="isHaCluster")
    def is_ha_cluster(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable high availability for the Database Instance.

        > **Important** Updates to `is_ha_cluster` will recreate the Database Instance.
        """
        return pulumi.get(self, "is_ha_cluster")

    @is_ha_cluster.setter
    def is_ha_cluster(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_ha_cluster", value)

    @_builtins.property
    @pulumi.getter(name="loadBalancer")
    def load_balancer(self) -> Optional[pulumi.Input['DatabaseInstanceLoadBalancerArgs']]:
        """
        List of Load Balancer endpoints of the Database Instance.
        """
        return pulumi.get(self, "load_balancer")

    @load_balancer.setter
    def load_balancer(self, value: Optional[pulumi.Input['DatabaseInstanceLoadBalancerArgs']]):
        pulumi.set(self, "load_balancer", value)

    @_builtins.property
    @pulumi.getter(name="logsPolicy")
    def logs_policy(self) -> Optional[pulumi.Input['DatabaseInstanceLogsPolicyArgs']]:
        """
        Logs policy configuration
        """
        return pulumi.get(self, "logs_policy")

    @logs_policy.setter
    def logs_policy(self, value: Optional[pulumi.Input['DatabaseInstanceLogsPolicyArgs']]):
        pulumi.set(self, "logs_policy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Database Instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the first user of the Database Instance. Only one of `password` or `password_wo` should be specified.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="passwordWo")
    def password_wo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        """
        return pulumi.get(self, "password_wo")

    @password_wo.setter
    def password_wo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password_wo", value)

    @_builtins.property
    @pulumi.getter(name="passwordWoVersion")
    def password_wo_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The version of the write-only password. To update the `password_wo`, you must also update the `password_wo_version`.
        """
        return pulumi.get(self, "password_wo_version")

    @password_wo_version.setter
    def password_wo_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "password_wo_version", value)

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]]]:
        """
        The private IPv4 address associated with the resource.
        """
        return pulumi.get(self, "private_ips")

    @private_ips.setter
    def private_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]]]):
        pulumi.set(self, "private_ips", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['DatabaseInstancePrivateNetworkArgs']]:
        """
        List of Private Networks endpoints of the Database Instance.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['DatabaseInstancePrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the Database
        Instance is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region
        in which the Database Instance should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of engine settings to be set on a running instance.
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "settings", value)

    @_builtins.property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of an existing snapshot to restore or create the Database Instance from. Conflicts with the `engine` parameter and backup settings.
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the Database Instance.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier for the first user of the Database Instance.

        > **Important** Updates to `user_name` will recreate the Database Instance.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Volume size (in GB). Cannot be used when `volume_type` is set to `lssd`.

        > **Important** Once your Database Instance reaches `disk_full` status, you should increase the volume size before making any other change to your Database Instance.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @volume_size_in_gb.setter
    def volume_size_in_gb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "volume_size_in_gb", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of volume where data are stored (`lssd`, `sbs_5k` or `sbs_15k`).
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "volume_type", value)


@pulumi.input_type
class _DatabaseInstanceState:
    def __init__(__self__, *,
                 backup_same_region: Optional[pulumi.Input[_builtins.bool]] = None,
                 backup_schedule_frequency: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_schedule_retention: Optional[pulumi.Input[_builtins.int]] = None,
                 certificate: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_backup: Optional[pulumi.Input[_builtins.bool]] = None,
                 encryption_at_rest: Optional[pulumi.Input[_builtins.bool]] = None,
                 endpoint_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_port: Optional[pulumi.Input[_builtins.int]] = None,
                 engine: Optional[pulumi.Input[_builtins.str]] = None,
                 init_settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 is_ha_cluster: Optional[pulumi.Input[_builtins.bool]] = None,
                 load_balancer: Optional[pulumi.Input['DatabaseInstanceLoadBalancerArgs']] = None,
                 logs_policy: Optional[pulumi.Input['DatabaseInstanceLogsPolicyArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo_version: Optional[pulumi.Input[_builtins.int]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]]] = None,
                 private_network: Optional[pulumi.Input['DatabaseInstancePrivateNetworkArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 read_replicas: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceReadReplicaArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 upgradable_versions: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceUpgradableVersionArgs']]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseInstance resources.
        :param pulumi.Input[_builtins.bool] backup_same_region: Boolean to store logical backups in the same region as the database instance
        :param pulumi.Input[_builtins.int] backup_schedule_frequency: Backup schedule frequency in hours
        :param pulumi.Input[_builtins.int] backup_schedule_retention: Backup schedule retention in days
        :param pulumi.Input[_builtins.str] certificate: Certificate of the Database Instance.
        :param pulumi.Input[_builtins.bool] disable_backup: Disable automated backup for the database instance
        :param pulumi.Input[_builtins.bool] encryption_at_rest: Enable or disable encryption at rest for the Database Instance.
        :param pulumi.Input[_builtins.str] endpoint_ip: (Deprecated) The IP of the Database Instance. Please use the private_network or the load_balancer attribute.
        :param pulumi.Input[_builtins.int] endpoint_port: (Deprecated) The port of the Database Instance. Please use the private_network or the load_balancer attribute.
        :param pulumi.Input[_builtins.str] engine: Database's engine version name (e.g., 'PostgreSQL-16', 'MySQL-8'). Changing this value triggers a blue/green upgrade using MajorUpgradeWorkflow with automatic endpoint migration
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] init_settings: Map of engine settings to be set at database initialisation.
        :param pulumi.Input[_builtins.bool] is_ha_cluster: Enable or disable high availability for the Database Instance.
               
               > **Important** Updates to `is_ha_cluster` will recreate the Database Instance.
        :param pulumi.Input['DatabaseInstanceLoadBalancerArgs'] load_balancer: List of Load Balancer endpoints of the Database Instance.
        :param pulumi.Input['DatabaseInstanceLogsPolicyArgs'] logs_policy: Logs policy configuration
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.str] node_type: The type of Database Instance you want to create (e.g. `db-dev-s`).
               
               > **Important** Updates to `node_type` will upgrade the Database Instance to the desired `node_type` without any
               interruption.
               
               > **Important** Once your Database Instance reaches `disk_full` status, if you are using `lssd` storage, you should upgrade the `node_type`, and if you are using `bssd` storage, you should increase the volume size before making any other changes to your Database Instance.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID the Database Instance is associated with.
        :param pulumi.Input[_builtins.str] password: Password for the first user of the Database Instance. Only one of `password` or `password_wo` should be specified.
        :param pulumi.Input[_builtins.str] password_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        :param pulumi.Input[_builtins.int] password_wo_version: The version of the write-only password. To update the `password_wo`, you must also update the `password_wo_version`.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]] private_ips: The private IPv4 address associated with the resource.
        :param pulumi.Input['DatabaseInstancePrivateNetworkArgs'] private_network: List of Private Networks endpoints of the Database Instance.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Database
               Instance is associated with.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceReadReplicaArgs']]] read_replicas: List of read replicas of the Database Instance.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Database Instance should be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] settings: Map of engine settings to be set on a running instance.
        :param pulumi.Input[_builtins.str] snapshot_id: The ID of an existing snapshot to restore or create the Database Instance from. Conflicts with the `engine` parameter and backup settings.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Database Instance.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceUpgradableVersionArgs']]] upgradable_versions: List of available engine versions for upgrade. Each version contains:
        :param pulumi.Input[_builtins.str] user_name: Identifier for the first user of the Database Instance.
               
               > **Important** Updates to `user_name` will recreate the Database Instance.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size (in GB). Cannot be used when `volume_type` is set to `lssd`.
               
               > **Important** Once your Database Instance reaches `disk_full` status, you should increase the volume size before making any other change to your Database Instance.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data are stored (`lssd`, `sbs_5k` or `sbs_15k`).
        """
        if backup_same_region is not None:
            pulumi.set(__self__, "backup_same_region", backup_same_region)
        if backup_schedule_frequency is not None:
            pulumi.set(__self__, "backup_schedule_frequency", backup_schedule_frequency)
        if backup_schedule_retention is not None:
            pulumi.set(__self__, "backup_schedule_retention", backup_schedule_retention)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if disable_backup is not None:
            pulumi.set(__self__, "disable_backup", disable_backup)
        if encryption_at_rest is not None:
            pulumi.set(__self__, "encryption_at_rest", encryption_at_rest)
        if endpoint_ip is not None:
            warnings.warn("""Please use the private_network or the load_balancer attribute""", DeprecationWarning)
            pulumi.log.warn("""endpoint_ip is deprecated: Please use the private_network or the load_balancer attribute""")
        if endpoint_ip is not None:
            pulumi.set(__self__, "endpoint_ip", endpoint_ip)
        if endpoint_port is not None:
            warnings.warn("""Please use the private_network or the load_balancer attribute""", DeprecationWarning)
            pulumi.log.warn("""endpoint_port is deprecated: Please use the private_network or the load_balancer attribute""")
        if endpoint_port is not None:
            pulumi.set(__self__, "endpoint_port", endpoint_port)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if init_settings is not None:
            pulumi.set(__self__, "init_settings", init_settings)
        if is_ha_cluster is not None:
            pulumi.set(__self__, "is_ha_cluster", is_ha_cluster)
        if load_balancer is not None:
            pulumi.set(__self__, "load_balancer", load_balancer)
        if logs_policy is not None:
            pulumi.set(__self__, "logs_policy", logs_policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_type is not None:
            pulumi.set(__self__, "node_type", node_type)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_wo is not None:
            pulumi.set(__self__, "password_wo", password_wo)
        if password_wo_version is not None:
            pulumi.set(__self__, "password_wo_version", password_wo_version)
        if private_ips is not None:
            pulumi.set(__self__, "private_ips", private_ips)
        if private_network is not None:
            pulumi.set(__self__, "private_network", private_network)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if read_replicas is not None:
            pulumi.set(__self__, "read_replicas", read_replicas)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if upgradable_versions is not None:
            pulumi.set(__self__, "upgradable_versions", upgradable_versions)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)
        if volume_size_in_gb is not None:
            pulumi.set(__self__, "volume_size_in_gb", volume_size_in_gb)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @_builtins.property
    @pulumi.getter(name="backupSameRegion")
    def backup_same_region(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean to store logical backups in the same region as the database instance
        """
        return pulumi.get(self, "backup_same_region")

    @backup_same_region.setter
    def backup_same_region(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "backup_same_region", value)

    @_builtins.property
    @pulumi.getter(name="backupScheduleFrequency")
    def backup_schedule_frequency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Backup schedule frequency in hours
        """
        return pulumi.get(self, "backup_schedule_frequency")

    @backup_schedule_frequency.setter
    def backup_schedule_frequency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_schedule_frequency", value)

    @_builtins.property
    @pulumi.getter(name="backupScheduleRetention")
    def backup_schedule_retention(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Backup schedule retention in days
        """
        return pulumi.get(self, "backup_schedule_retention")

    @backup_schedule_retention.setter
    def backup_schedule_retention(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_schedule_retention", value)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Certificate of the Database Instance.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "certificate", value)

    @_builtins.property
    @pulumi.getter(name="disableBackup")
    def disable_backup(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable automated backup for the database instance
        """
        return pulumi.get(self, "disable_backup")

    @disable_backup.setter
    def disable_backup(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_backup", value)

    @_builtins.property
    @pulumi.getter(name="encryptionAtRest")
    def encryption_at_rest(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable encryption at rest for the Database Instance.
        """
        return pulumi.get(self, "encryption_at_rest")

    @encryption_at_rest.setter
    def encryption_at_rest(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "encryption_at_rest", value)

    @_builtins.property
    @pulumi.getter(name="endpointIp")
    @_utilities.deprecated("""Please use the private_network or the load_balancer attribute""")
    def endpoint_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Deprecated) The IP of the Database Instance. Please use the private_network or the load_balancer attribute.
        """
        return pulumi.get(self, "endpoint_ip")

    @endpoint_ip.setter
    def endpoint_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_ip", value)

    @_builtins.property
    @pulumi.getter(name="endpointPort")
    @_utilities.deprecated("""Please use the private_network or the load_balancer attribute""")
    def endpoint_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (Deprecated) The port of the Database Instance. Please use the private_network or the load_balancer attribute.
        """
        return pulumi.get(self, "endpoint_port")

    @endpoint_port.setter
    def endpoint_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "endpoint_port", value)

    @_builtins.property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Database's engine version name (e.g., 'PostgreSQL-16', 'MySQL-8'). Changing this value triggers a blue/green upgrade using MajorUpgradeWorkflow with automatic endpoint migration
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "engine", value)

    @_builtins.property
    @pulumi.getter(name="initSettings")
    def init_settings(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of engine settings to be set at database initialisation.
        """
        return pulumi.get(self, "init_settings")

    @init_settings.setter
    def init_settings(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "init_settings", value)

    @_builtins.property
    @pulumi.getter(name="isHaCluster")
    def is_ha_cluster(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable high availability for the Database Instance.

        > **Important** Updates to `is_ha_cluster` will recreate the Database Instance.
        """
        return pulumi.get(self, "is_ha_cluster")

    @is_ha_cluster.setter
    def is_ha_cluster(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_ha_cluster", value)

    @_builtins.property
    @pulumi.getter(name="loadBalancer")
    def load_balancer(self) -> Optional[pulumi.Input['DatabaseInstanceLoadBalancerArgs']]:
        """
        List of Load Balancer endpoints of the Database Instance.
        """
        return pulumi.get(self, "load_balancer")

    @load_balancer.setter
    def load_balancer(self, value: Optional[pulumi.Input['DatabaseInstanceLoadBalancerArgs']]):
        pulumi.set(self, "load_balancer", value)

    @_builtins.property
    @pulumi.getter(name="logsPolicy")
    def logs_policy(self) -> Optional[pulumi.Input['DatabaseInstanceLogsPolicyArgs']]:
        """
        Logs policy configuration
        """
        return pulumi.get(self, "logs_policy")

    @logs_policy.setter
    def logs_policy(self, value: Optional[pulumi.Input['DatabaseInstanceLogsPolicyArgs']]):
        pulumi.set(self, "logs_policy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Database Instance.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of Database Instance you want to create (e.g. `db-dev-s`).

        > **Important** Updates to `node_type` will upgrade the Database Instance to the desired `node_type` without any
        interruption.

        > **Important** Once your Database Instance reaches `disk_full` status, if you are using `lssd` storage, you should upgrade the `node_type`, and if you are using `bssd` storage, you should increase the volume size before making any other changes to your Database Instance.
        """
        return pulumi.get(self, "node_type")

    @node_type.setter
    def node_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "node_type", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID the Database Instance is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for the first user of the Database Instance. Only one of `password` or `password_wo` should be specified.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="passwordWo")
    def password_wo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        """
        return pulumi.get(self, "password_wo")

    @password_wo.setter
    def password_wo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password_wo", value)

    @_builtins.property
    @pulumi.getter(name="passwordWoVersion")
    def password_wo_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The version of the write-only password. To update the `password_wo`, you must also update the `password_wo_version`.
        """
        return pulumi.get(self, "password_wo_version")

    @password_wo_version.setter
    def password_wo_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "password_wo_version", value)

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]]]:
        """
        The private IPv4 address associated with the resource.
        """
        return pulumi.get(self, "private_ips")

    @private_ips.setter
    def private_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstancePrivateIpArgs']]]]):
        pulumi.set(self, "private_ips", value)

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> Optional[pulumi.Input['DatabaseInstancePrivateNetworkArgs']]:
        """
        List of Private Networks endpoints of the Database Instance.
        """
        return pulumi.get(self, "private_network")

    @private_network.setter
    def private_network(self, value: Optional[pulumi.Input['DatabaseInstancePrivateNetworkArgs']]):
        pulumi.set(self, "private_network", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the Database
        Instance is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="readReplicas")
    def read_replicas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceReadReplicaArgs']]]]:
        """
        List of read replicas of the Database Instance.
        """
        return pulumi.get(self, "read_replicas")

    @read_replicas.setter
    def read_replicas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceReadReplicaArgs']]]]):
        pulumi.set(self, "read_replicas", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region
        in which the Database Instance should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of engine settings to be set on a running instance.
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "settings", value)

    @_builtins.property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of an existing snapshot to restore or create the Database Instance from. Conflicts with the `engine` parameter and backup settings.
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The tags associated with the Database Instance.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="upgradableVersions")
    def upgradable_versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceUpgradableVersionArgs']]]]:
        """
        List of available engine versions for upgrade. Each version contains:
        """
        return pulumi.get(self, "upgradable_versions")

    @upgradable_versions.setter
    def upgradable_versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceUpgradableVersionArgs']]]]):
        pulumi.set(self, "upgradable_versions", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier for the first user of the Database Instance.

        > **Important** Updates to `user_name` will recreate the Database Instance.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Volume size (in GB). Cannot be used when `volume_type` is set to `lssd`.

        > **Important** Once your Database Instance reaches `disk_full` status, you should increase the volume size before making any other change to your Database Instance.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @volume_size_in_gb.setter
    def volume_size_in_gb(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "volume_size_in_gb", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of volume where data are stored (`lssd`, `sbs_5k` or `sbs_15k`).
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "volume_type", value)


warnings.warn("""scaleway.index/databaseinstance.DatabaseInstance has been deprecated in favor of scaleway.databases/instance.Instance""", DeprecationWarning)


@pulumi.type_token("scaleway:index/databaseInstance:DatabaseInstance")
class DatabaseInstance(pulumi.CustomResource):
    warnings.warn("""scaleway.index/databaseinstance.DatabaseInstance has been deprecated in favor of scaleway.databases/instance.Instance""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_same_region: Optional[pulumi.Input[_builtins.bool]] = None,
                 backup_schedule_frequency: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_schedule_retention: Optional[pulumi.Input[_builtins.int]] = None,
                 disable_backup: Optional[pulumi.Input[_builtins.bool]] = None,
                 encryption_at_rest: Optional[pulumi.Input[_builtins.bool]] = None,
                 engine: Optional[pulumi.Input[_builtins.str]] = None,
                 init_settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 is_ha_cluster: Optional[pulumi.Input[_builtins.bool]] = None,
                 load_balancer: Optional[pulumi.Input[Union['DatabaseInstanceLoadBalancerArgs', 'DatabaseInstanceLoadBalancerArgsDict']]] = None,
                 logs_policy: Optional[pulumi.Input[Union['DatabaseInstanceLogsPolicyArgs', 'DatabaseInstanceLogsPolicyArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo_version: Optional[pulumi.Input[_builtins.int]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstancePrivateIpArgs', 'DatabaseInstancePrivateIpArgsDict']]]]] = None,
                 private_network: Optional[pulumi.Input[Union['DatabaseInstancePrivateNetworkArgs', 'DatabaseInstancePrivateNetworkArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Example Basic
        main = scaleway.databases.Instance("main",
            name="test-rdb",
            node_type="DB-DEV-S",
            engine="PostgreSQL-15",
            is_ha_cluster=True,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret",
            encryption_at_rest=True)
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Example Engine Upgrade
        # Initial creation with PostgreSQL 14
        main = scaleway.databases.Instance("main",
            name="my-database",
            node_type="DB-DEV-S",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_user",
            password="thiZ_is_v&ry_s3cret")
        pulumi.export("upgradableVersions", main.upgradable_versions)
        ```

        ## Import

        Database Instance can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/databaseInstance:DatabaseInstance rdb01 fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] backup_same_region: Boolean to store logical backups in the same region as the database instance
        :param pulumi.Input[_builtins.int] backup_schedule_frequency: Backup schedule frequency in hours
        :param pulumi.Input[_builtins.int] backup_schedule_retention: Backup schedule retention in days
        :param pulumi.Input[_builtins.bool] disable_backup: Disable automated backup for the database instance
        :param pulumi.Input[_builtins.bool] encryption_at_rest: Enable or disable encryption at rest for the Database Instance.
        :param pulumi.Input[_builtins.str] engine: Database's engine version name (e.g., 'PostgreSQL-16', 'MySQL-8'). Changing this value triggers a blue/green upgrade using MajorUpgradeWorkflow with automatic endpoint migration
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] init_settings: Map of engine settings to be set at database initialisation.
        :param pulumi.Input[_builtins.bool] is_ha_cluster: Enable or disable high availability for the Database Instance.
               
               > **Important** Updates to `is_ha_cluster` will recreate the Database Instance.
        :param pulumi.Input[Union['DatabaseInstanceLoadBalancerArgs', 'DatabaseInstanceLoadBalancerArgsDict']] load_balancer: List of Load Balancer endpoints of the Database Instance.
        :param pulumi.Input[Union['DatabaseInstanceLogsPolicyArgs', 'DatabaseInstanceLogsPolicyArgsDict']] logs_policy: Logs policy configuration
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.str] node_type: The type of Database Instance you want to create (e.g. `db-dev-s`).
               
               > **Important** Updates to `node_type` will upgrade the Database Instance to the desired `node_type` without any
               interruption.
               
               > **Important** Once your Database Instance reaches `disk_full` status, if you are using `lssd` storage, you should upgrade the `node_type`, and if you are using `bssd` storage, you should increase the volume size before making any other changes to your Database Instance.
        :param pulumi.Input[_builtins.str] password: Password for the first user of the Database Instance. Only one of `password` or `password_wo` should be specified.
        :param pulumi.Input[_builtins.str] password_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        :param pulumi.Input[_builtins.int] password_wo_version: The version of the write-only password. To update the `password_wo`, you must also update the `password_wo_version`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstancePrivateIpArgs', 'DatabaseInstancePrivateIpArgsDict']]]] private_ips: The private IPv4 address associated with the resource.
        :param pulumi.Input[Union['DatabaseInstancePrivateNetworkArgs', 'DatabaseInstancePrivateNetworkArgsDict']] private_network: List of Private Networks endpoints of the Database Instance.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Database
               Instance is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Database Instance should be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] settings: Map of engine settings to be set on a running instance.
        :param pulumi.Input[_builtins.str] snapshot_id: The ID of an existing snapshot to restore or create the Database Instance from. Conflicts with the `engine` parameter and backup settings.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Database Instance.
        :param pulumi.Input[_builtins.str] user_name: Identifier for the first user of the Database Instance.
               
               > **Important** Updates to `user_name` will recreate the Database Instance.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size (in GB). Cannot be used when `volume_type` is set to `lssd`.
               
               > **Important** Once your Database Instance reaches `disk_full` status, you should increase the volume size before making any other change to your Database Instance.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data are stored (`lssd`, `sbs_5k` or `sbs_15k`).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Example Basic
        main = scaleway.databases.Instance("main",
            name="test-rdb",
            node_type="DB-DEV-S",
            engine="PostgreSQL-15",
            is_ha_cluster=True,
            disable_backup=True,
            user_name="my_initial_user",
            password="thiZ_is_v&ry_s3cret",
            encryption_at_rest=True)
        ```

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Example Engine Upgrade
        # Initial creation with PostgreSQL 14
        main = scaleway.databases.Instance("main",
            name="my-database",
            node_type="DB-DEV-S",
            engine="PostgreSQL-14",
            is_ha_cluster=False,
            disable_backup=True,
            user_name="my_user",
            password="thiZ_is_v&ry_s3cret")
        pulumi.export("upgradableVersions", main.upgradable_versions)
        ```

        ## Import

        Database Instance can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/databaseInstance:DatabaseInstance rdb01 fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_same_region: Optional[pulumi.Input[_builtins.bool]] = None,
                 backup_schedule_frequency: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_schedule_retention: Optional[pulumi.Input[_builtins.int]] = None,
                 disable_backup: Optional[pulumi.Input[_builtins.bool]] = None,
                 encryption_at_rest: Optional[pulumi.Input[_builtins.bool]] = None,
                 engine: Optional[pulumi.Input[_builtins.str]] = None,
                 init_settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 is_ha_cluster: Optional[pulumi.Input[_builtins.bool]] = None,
                 load_balancer: Optional[pulumi.Input[Union['DatabaseInstanceLoadBalancerArgs', 'DatabaseInstanceLoadBalancerArgsDict']]] = None,
                 logs_policy: Optional[pulumi.Input[Union['DatabaseInstanceLogsPolicyArgs', 'DatabaseInstanceLogsPolicyArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_type: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 password_wo_version: Optional[pulumi.Input[_builtins.int]] = None,
                 private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstancePrivateIpArgs', 'DatabaseInstancePrivateIpArgsDict']]]]] = None,
                 private_network: Optional[pulumi.Input[Union['DatabaseInstancePrivateNetworkArgs', 'DatabaseInstancePrivateNetworkArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""DatabaseInstance is deprecated: scaleway.index/databaseinstance.DatabaseInstance has been deprecated in favor of scaleway.databases/instance.Instance""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseInstanceArgs.__new__(DatabaseInstanceArgs)

            __props__.__dict__["backup_same_region"] = backup_same_region
            __props__.__dict__["backup_schedule_frequency"] = backup_schedule_frequency
            __props__.__dict__["backup_schedule_retention"] = backup_schedule_retention
            __props__.__dict__["disable_backup"] = disable_backup
            __props__.__dict__["encryption_at_rest"] = encryption_at_rest
            __props__.__dict__["engine"] = engine
            __props__.__dict__["init_settings"] = init_settings
            __props__.__dict__["is_ha_cluster"] = is_ha_cluster
            __props__.__dict__["load_balancer"] = load_balancer
            __props__.__dict__["logs_policy"] = logs_policy
            __props__.__dict__["name"] = name
            if node_type is None and not opts.urn:
                raise TypeError("Missing required property 'node_type'")
            __props__.__dict__["node_type"] = node_type
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["password_wo"] = None if password_wo is None else pulumi.Output.secret(password_wo)
            __props__.__dict__["password_wo_version"] = password_wo_version
            __props__.__dict__["private_ips"] = private_ips
            __props__.__dict__["private_network"] = private_network
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["settings"] = settings
            __props__.__dict__["snapshot_id"] = snapshot_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["user_name"] = user_name
            __props__.__dict__["volume_size_in_gb"] = volume_size_in_gb
            __props__.__dict__["volume_type"] = volume_type
            __props__.__dict__["certificate"] = None
            __props__.__dict__["endpoint_ip"] = None
            __props__.__dict__["endpoint_port"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["read_replicas"] = None
            __props__.__dict__["upgradable_versions"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password", "passwordWo"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DatabaseInstance, __self__).__init__(
            'scaleway:index/databaseInstance:DatabaseInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_same_region: Optional[pulumi.Input[_builtins.bool]] = None,
            backup_schedule_frequency: Optional[pulumi.Input[_builtins.int]] = None,
            backup_schedule_retention: Optional[pulumi.Input[_builtins.int]] = None,
            certificate: Optional[pulumi.Input[_builtins.str]] = None,
            disable_backup: Optional[pulumi.Input[_builtins.bool]] = None,
            encryption_at_rest: Optional[pulumi.Input[_builtins.bool]] = None,
            endpoint_ip: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint_port: Optional[pulumi.Input[_builtins.int]] = None,
            engine: Optional[pulumi.Input[_builtins.str]] = None,
            init_settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            is_ha_cluster: Optional[pulumi.Input[_builtins.bool]] = None,
            load_balancer: Optional[pulumi.Input[Union['DatabaseInstanceLoadBalancerArgs', 'DatabaseInstanceLoadBalancerArgsDict']]] = None,
            logs_policy: Optional[pulumi.Input[Union['DatabaseInstanceLogsPolicyArgs', 'DatabaseInstanceLogsPolicyArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            node_type: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            password_wo: Optional[pulumi.Input[_builtins.str]] = None,
            password_wo_version: Optional[pulumi.Input[_builtins.int]] = None,
            private_ips: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstancePrivateIpArgs', 'DatabaseInstancePrivateIpArgsDict']]]]] = None,
            private_network: Optional[pulumi.Input[Union['DatabaseInstancePrivateNetworkArgs', 'DatabaseInstancePrivateNetworkArgsDict']]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            read_replicas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceReadReplicaArgs', 'DatabaseInstanceReadReplicaArgsDict']]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            settings: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            upgradable_versions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceUpgradableVersionArgs', 'DatabaseInstanceUpgradableVersionArgsDict']]]]] = None,
            user_name: Optional[pulumi.Input[_builtins.str]] = None,
            volume_size_in_gb: Optional[pulumi.Input[_builtins.int]] = None,
            volume_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'DatabaseInstance':
        """
        Get an existing DatabaseInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] backup_same_region: Boolean to store logical backups in the same region as the database instance
        :param pulumi.Input[_builtins.int] backup_schedule_frequency: Backup schedule frequency in hours
        :param pulumi.Input[_builtins.int] backup_schedule_retention: Backup schedule retention in days
        :param pulumi.Input[_builtins.str] certificate: Certificate of the Database Instance.
        :param pulumi.Input[_builtins.bool] disable_backup: Disable automated backup for the database instance
        :param pulumi.Input[_builtins.bool] encryption_at_rest: Enable or disable encryption at rest for the Database Instance.
        :param pulumi.Input[_builtins.str] endpoint_ip: (Deprecated) The IP of the Database Instance. Please use the private_network or the load_balancer attribute.
        :param pulumi.Input[_builtins.int] endpoint_port: (Deprecated) The port of the Database Instance. Please use the private_network or the load_balancer attribute.
        :param pulumi.Input[_builtins.str] engine: Database's engine version name (e.g., 'PostgreSQL-16', 'MySQL-8'). Changing this value triggers a blue/green upgrade using MajorUpgradeWorkflow with automatic endpoint migration
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] init_settings: Map of engine settings to be set at database initialisation.
        :param pulumi.Input[_builtins.bool] is_ha_cluster: Enable or disable high availability for the Database Instance.
               
               > **Important** Updates to `is_ha_cluster` will recreate the Database Instance.
        :param pulumi.Input[Union['DatabaseInstanceLoadBalancerArgs', 'DatabaseInstanceLoadBalancerArgsDict']] load_balancer: List of Load Balancer endpoints of the Database Instance.
        :param pulumi.Input[Union['DatabaseInstanceLogsPolicyArgs', 'DatabaseInstanceLogsPolicyArgsDict']] logs_policy: Logs policy configuration
        :param pulumi.Input[_builtins.str] name: The name of the Database Instance.
        :param pulumi.Input[_builtins.str] node_type: The type of Database Instance you want to create (e.g. `db-dev-s`).
               
               > **Important** Updates to `node_type` will upgrade the Database Instance to the desired `node_type` without any
               interruption.
               
               > **Important** Once your Database Instance reaches `disk_full` status, if you are using `lssd` storage, you should upgrade the `node_type`, and if you are using `bssd` storage, you should increase the volume size before making any other changes to your Database Instance.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID the Database Instance is associated with.
        :param pulumi.Input[_builtins.str] password: Password for the first user of the Database Instance. Only one of `password` or `password_wo` should be specified.
        :param pulumi.Input[_builtins.str] password_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        :param pulumi.Input[_builtins.int] password_wo_version: The version of the write-only password. To update the `password_wo`, you must also update the `password_wo_version`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstancePrivateIpArgs', 'DatabaseInstancePrivateIpArgsDict']]]] private_ips: The private IPv4 address associated with the resource.
        :param pulumi.Input[Union['DatabaseInstancePrivateNetworkArgs', 'DatabaseInstancePrivateNetworkArgsDict']] private_network: List of Private Networks endpoints of the Database Instance.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Database
               Instance is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceReadReplicaArgs', 'DatabaseInstanceReadReplicaArgsDict']]]] read_replicas: List of read replicas of the Database Instance.
        :param pulumi.Input[_builtins.str] region: `region`) The region
               in which the Database Instance should be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] settings: Map of engine settings to be set on a running instance.
        :param pulumi.Input[_builtins.str] snapshot_id: The ID of an existing snapshot to restore or create the Database Instance from. Conflicts with the `engine` parameter and backup settings.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The tags associated with the Database Instance.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceUpgradableVersionArgs', 'DatabaseInstanceUpgradableVersionArgsDict']]]] upgradable_versions: List of available engine versions for upgrade. Each version contains:
        :param pulumi.Input[_builtins.str] user_name: Identifier for the first user of the Database Instance.
               
               > **Important** Updates to `user_name` will recreate the Database Instance.
        :param pulumi.Input[_builtins.int] volume_size_in_gb: Volume size (in GB). Cannot be used when `volume_type` is set to `lssd`.
               
               > **Important** Once your Database Instance reaches `disk_full` status, you should increase the volume size before making any other change to your Database Instance.
        :param pulumi.Input[_builtins.str] volume_type: Type of volume where data are stored (`lssd`, `sbs_5k` or `sbs_15k`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseInstanceState.__new__(_DatabaseInstanceState)

        __props__.__dict__["backup_same_region"] = backup_same_region
        __props__.__dict__["backup_schedule_frequency"] = backup_schedule_frequency
        __props__.__dict__["backup_schedule_retention"] = backup_schedule_retention
        __props__.__dict__["certificate"] = certificate
        __props__.__dict__["disable_backup"] = disable_backup
        __props__.__dict__["encryption_at_rest"] = encryption_at_rest
        __props__.__dict__["endpoint_ip"] = endpoint_ip
        __props__.__dict__["endpoint_port"] = endpoint_port
        __props__.__dict__["engine"] = engine
        __props__.__dict__["init_settings"] = init_settings
        __props__.__dict__["is_ha_cluster"] = is_ha_cluster
        __props__.__dict__["load_balancer"] = load_balancer
        __props__.__dict__["logs_policy"] = logs_policy
        __props__.__dict__["name"] = name
        __props__.__dict__["node_type"] = node_type
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["password"] = password
        __props__.__dict__["password_wo"] = password_wo
        __props__.__dict__["password_wo_version"] = password_wo_version
        __props__.__dict__["private_ips"] = private_ips
        __props__.__dict__["private_network"] = private_network
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["read_replicas"] = read_replicas
        __props__.__dict__["region"] = region
        __props__.__dict__["settings"] = settings
        __props__.__dict__["snapshot_id"] = snapshot_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["upgradable_versions"] = upgradable_versions
        __props__.__dict__["user_name"] = user_name
        __props__.__dict__["volume_size_in_gb"] = volume_size_in_gb
        __props__.__dict__["volume_type"] = volume_type
        return DatabaseInstance(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="backupSameRegion")
    def backup_same_region(self) -> pulumi.Output[_builtins.bool]:
        """
        Boolean to store logical backups in the same region as the database instance
        """
        return pulumi.get(self, "backup_same_region")

    @_builtins.property
    @pulumi.getter(name="backupScheduleFrequency")
    def backup_schedule_frequency(self) -> pulumi.Output[_builtins.int]:
        """
        Backup schedule frequency in hours
        """
        return pulumi.get(self, "backup_schedule_frequency")

    @_builtins.property
    @pulumi.getter(name="backupScheduleRetention")
    def backup_schedule_retention(self) -> pulumi.Output[_builtins.int]:
        """
        Backup schedule retention in days
        """
        return pulumi.get(self, "backup_schedule_retention")

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> pulumi.Output[_builtins.str]:
        """
        Certificate of the Database Instance.
        """
        return pulumi.get(self, "certificate")

    @_builtins.property
    @pulumi.getter(name="disableBackup")
    def disable_backup(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Disable automated backup for the database instance
        """
        return pulumi.get(self, "disable_backup")

    @_builtins.property
    @pulumi.getter(name="encryptionAtRest")
    def encryption_at_rest(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable or disable encryption at rest for the Database Instance.
        """
        return pulumi.get(self, "encryption_at_rest")

    @_builtins.property
    @pulumi.getter(name="endpointIp")
    @_utilities.deprecated("""Please use the private_network or the load_balancer attribute""")
    def endpoint_ip(self) -> pulumi.Output[_builtins.str]:
        """
        (Deprecated) The IP of the Database Instance. Please use the private_network or the load_balancer attribute.
        """
        return pulumi.get(self, "endpoint_ip")

    @_builtins.property
    @pulumi.getter(name="endpointPort")
    @_utilities.deprecated("""Please use the private_network or the load_balancer attribute""")
    def endpoint_port(self) -> pulumi.Output[_builtins.int]:
        """
        (Deprecated) The port of the Database Instance. Please use the private_network or the load_balancer attribute.
        """
        return pulumi.get(self, "endpoint_port")

    @_builtins.property
    @pulumi.getter
    def engine(self) -> pulumi.Output[_builtins.str]:
        """
        Database's engine version name (e.g., 'PostgreSQL-16', 'MySQL-8'). Changing this value triggers a blue/green upgrade using MajorUpgradeWorkflow with automatic endpoint migration
        """
        return pulumi.get(self, "engine")

    @_builtins.property
    @pulumi.getter(name="initSettings")
    def init_settings(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Map of engine settings to be set at database initialisation.
        """
        return pulumi.get(self, "init_settings")

    @_builtins.property
    @pulumi.getter(name="isHaCluster")
    def is_ha_cluster(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable or disable high availability for the Database Instance.

        > **Important** Updates to `is_ha_cluster` will recreate the Database Instance.
        """
        return pulumi.get(self, "is_ha_cluster")

    @_builtins.property
    @pulumi.getter(name="loadBalancer")
    def load_balancer(self) -> pulumi.Output['outputs.DatabaseInstanceLoadBalancer']:
        """
        List of Load Balancer endpoints of the Database Instance.
        """
        return pulumi.get(self, "load_balancer")

    @_builtins.property
    @pulumi.getter(name="logsPolicy")
    def logs_policy(self) -> pulumi.Output['outputs.DatabaseInstanceLogsPolicy']:
        """
        Logs policy configuration
        """
        return pulumi.get(self, "logs_policy")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Database Instance.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of Database Instance you want to create (e.g. `db-dev-s`).

        > **Important** Updates to `node_type` will upgrade the Database Instance to the desired `node_type` without any
        interruption.

        > **Important** Once your Database Instance reaches `disk_full` status, if you are using `lssd` storage, you should upgrade the `node_type`, and if you are using `bssd` storage, you should increase the volume size before making any other changes to your Database Instance.
        """
        return pulumi.get(self, "node_type")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The organization ID the Database Instance is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password for the first user of the Database Instance. Only one of `password` or `password_wo` should be specified.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="passwordWo")
    def password_wo(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        """
        return pulumi.get(self, "password_wo")

    @_builtins.property
    @pulumi.getter(name="passwordWoVersion")
    def password_wo_version(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The version of the write-only password. To update the `password_wo`, you must also update the `password_wo_version`.
        """
        return pulumi.get(self, "password_wo_version")

    @_builtins.property
    @pulumi.getter(name="privateIps")
    def private_ips(self) -> pulumi.Output[Sequence['outputs.DatabaseInstancePrivateIp']]:
        """
        The private IPv4 address associated with the resource.
        """
        return pulumi.get(self, "private_ips")

    @_builtins.property
    @pulumi.getter(name="privateNetwork")
    def private_network(self) -> pulumi.Output[Optional['outputs.DatabaseInstancePrivateNetwork']]:
        """
        List of Private Networks endpoints of the Database Instance.
        """
        return pulumi.get(self, "private_network")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the Database
        Instance is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="readReplicas")
    def read_replicas(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceReadReplica']]:
        """
        List of read replicas of the Database Instance.
        """
        return pulumi.get(self, "read_replicas")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region
        in which the Database Instance should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        """
        Map of engine settings to be set on a running instance.
        """
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of an existing snapshot to restore or create the Database Instance from. Conflicts with the `engine` parameter and backup settings.
        """
        return pulumi.get(self, "snapshot_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The tags associated with the Database Instance.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="upgradableVersions")
    def upgradable_versions(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceUpgradableVersion']]:
        """
        List of available engine versions for upgrade. Each version contains:
        """
        return pulumi.get(self, "upgradable_versions")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier for the first user of the Database Instance.

        > **Important** Updates to `user_name` will recreate the Database Instance.
        """
        return pulumi.get(self, "user_name")

    @_builtins.property
    @pulumi.getter(name="volumeSizeInGb")
    def volume_size_in_gb(self) -> pulumi.Output[_builtins.int]:
        """
        Volume size (in GB). Cannot be used when `volume_type` is set to `lssd`.

        > **Important** Once your Database Instance reaches `disk_full` status, you should increase the volume size before making any other change to your Database Instance.
        """
        return pulumi.get(self, "volume_size_in_gb")

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Type of volume where data are stored (`lssd`, `sbs_5k` or `sbs_15k`).
        """
        return pulumi.get(self, "volume_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RegistrationArgs', 'Registration']

@pulumi.input_type
class RegistrationArgs:
    def __init__(__self__, *,
                 domain_names: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 auto_renew: Optional[pulumi.Input[_builtins.bool]] = None,
                 dnssec: Optional[pulumi.Input[_builtins.bool]] = None,
                 duration_in_years: Optional[pulumi.Input[_builtins.int]] = None,
                 owner_contact: Optional[pulumi.Input['RegistrationOwnerContactArgs']] = None,
                 owner_contact_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Registration resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_names: : A list of domain names to be registered.
        :param pulumi.Input[_builtins.bool] auto_renew: : Enables or disables auto-renewal.
        :param pulumi.Input[_builtins.bool] dnssec: : Enables or disables DNSSEC.
        :param pulumi.Input[_builtins.int] duration_in_years: : The registration period in years.
        :param pulumi.Input['RegistrationOwnerContactArgs'] owner_contact: : Details of the owner contact.
        :param pulumi.Input[_builtins.str] owner_contact_id: : The ID of an existing owner contact.
        :param pulumi.Input[_builtins.str] project_id: : The Scaleway project ID.
        """
        pulumi.set(__self__, "domain_names", domain_names)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if dnssec is not None:
            pulumi.set(__self__, "dnssec", dnssec)
        if duration_in_years is not None:
            pulumi.set(__self__, "duration_in_years", duration_in_years)
        if owner_contact is not None:
            pulumi.set(__self__, "owner_contact", owner_contact)
        if owner_contact_id is not None:
            pulumi.set(__self__, "owner_contact_id", owner_contact_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter(name="domainNames")
    def domain_names(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        : A list of domain names to be registered.
        """
        return pulumi.get(self, "domain_names")

    @domain_names.setter
    def domain_names(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "domain_names", value)

    @_builtins.property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        : Enables or disables auto-renewal.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @_builtins.property
    @pulumi.getter
    def dnssec(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        : Enables or disables DNSSEC.
        """
        return pulumi.get(self, "dnssec")

    @dnssec.setter
    def dnssec(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dnssec", value)

    @_builtins.property
    @pulumi.getter(name="durationInYears")
    def duration_in_years(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        : The registration period in years.
        """
        return pulumi.get(self, "duration_in_years")

    @duration_in_years.setter
    def duration_in_years(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "duration_in_years", value)

    @_builtins.property
    @pulumi.getter(name="ownerContact")
    def owner_contact(self) -> Optional[pulumi.Input['RegistrationOwnerContactArgs']]:
        """
        : Details of the owner contact.
        """
        return pulumi.get(self, "owner_contact")

    @owner_contact.setter
    def owner_contact(self, value: Optional[pulumi.Input['RegistrationOwnerContactArgs']]):
        pulumi.set(self, "owner_contact", value)

    @_builtins.property
    @pulumi.getter(name="ownerContactId")
    def owner_contact_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        : The ID of an existing owner contact.
        """
        return pulumi.get(self, "owner_contact_id")

    @owner_contact_id.setter
    def owner_contact_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_contact_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        : The Scaleway project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _RegistrationState:
    def __init__(__self__, *,
                 administrative_contacts: Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationAdministrativeContactArgs']]]] = None,
                 auto_renew: Optional[pulumi.Input[_builtins.bool]] = None,
                 dnssec: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 ds_records: Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationDsRecordArgs']]]] = None,
                 duration_in_years: Optional[pulumi.Input[_builtins.int]] = None,
                 owner_contact: Optional[pulumi.Input['RegistrationOwnerContactArgs']] = None,
                 owner_contact_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 task_id: Optional[pulumi.Input[_builtins.str]] = None,
                 technical_contacts: Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationTechnicalContactArgs']]]] = None):
        """
        Input properties used for looking up and filtering Registration resources.
        :param pulumi.Input[Sequence[pulumi.Input['RegistrationAdministrativeContactArgs']]] administrative_contacts: : Administrative contact information.
        :param pulumi.Input[_builtins.bool] auto_renew: : Enables or disables auto-renewal.
        :param pulumi.Input[_builtins.bool] dnssec: : Enables or disables DNSSEC.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_names: : A list of domain names to be registered.
        :param pulumi.Input[Sequence[pulumi.Input['RegistrationDsRecordArgs']]] ds_records: DNSSEC DS record configuration.
        :param pulumi.Input[_builtins.int] duration_in_years: : The registration period in years.
        :param pulumi.Input['RegistrationOwnerContactArgs'] owner_contact: : Details of the owner contact.
        :param pulumi.Input[_builtins.str] owner_contact_id: : The ID of an existing owner contact.
        :param pulumi.Input[_builtins.str] project_id: : The Scaleway project ID.
        :param pulumi.Input[_builtins.str] task_id: ID of the task that created the domain.
        :param pulumi.Input[Sequence[pulumi.Input['RegistrationTechnicalContactArgs']]] technical_contacts: : Technical contact information.
        """
        if administrative_contacts is not None:
            pulumi.set(__self__, "administrative_contacts", administrative_contacts)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if dnssec is not None:
            pulumi.set(__self__, "dnssec", dnssec)
        if domain_names is not None:
            pulumi.set(__self__, "domain_names", domain_names)
        if ds_records is not None:
            pulumi.set(__self__, "ds_records", ds_records)
        if duration_in_years is not None:
            pulumi.set(__self__, "duration_in_years", duration_in_years)
        if owner_contact is not None:
            pulumi.set(__self__, "owner_contact", owner_contact)
        if owner_contact_id is not None:
            pulumi.set(__self__, "owner_contact_id", owner_contact_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if task_id is not None:
            pulumi.set(__self__, "task_id", task_id)
        if technical_contacts is not None:
            pulumi.set(__self__, "technical_contacts", technical_contacts)

    @_builtins.property
    @pulumi.getter(name="administrativeContacts")
    def administrative_contacts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationAdministrativeContactArgs']]]]:
        """
        : Administrative contact information.
        """
        return pulumi.get(self, "administrative_contacts")

    @administrative_contacts.setter
    def administrative_contacts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationAdministrativeContactArgs']]]]):
        pulumi.set(self, "administrative_contacts", value)

    @_builtins.property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        : Enables or disables auto-renewal.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @_builtins.property
    @pulumi.getter
    def dnssec(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        : Enables or disables DNSSEC.
        """
        return pulumi.get(self, "dnssec")

    @dnssec.setter
    def dnssec(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dnssec", value)

    @_builtins.property
    @pulumi.getter(name="domainNames")
    def domain_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        : A list of domain names to be registered.
        """
        return pulumi.get(self, "domain_names")

    @domain_names.setter
    def domain_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "domain_names", value)

    @_builtins.property
    @pulumi.getter(name="dsRecords")
    def ds_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationDsRecordArgs']]]]:
        """
        DNSSEC DS record configuration.
        """
        return pulumi.get(self, "ds_records")

    @ds_records.setter
    def ds_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationDsRecordArgs']]]]):
        pulumi.set(self, "ds_records", value)

    @_builtins.property
    @pulumi.getter(name="durationInYears")
    def duration_in_years(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        : The registration period in years.
        """
        return pulumi.get(self, "duration_in_years")

    @duration_in_years.setter
    def duration_in_years(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "duration_in_years", value)

    @_builtins.property
    @pulumi.getter(name="ownerContact")
    def owner_contact(self) -> Optional[pulumi.Input['RegistrationOwnerContactArgs']]:
        """
        : Details of the owner contact.
        """
        return pulumi.get(self, "owner_contact")

    @owner_contact.setter
    def owner_contact(self, value: Optional[pulumi.Input['RegistrationOwnerContactArgs']]):
        pulumi.set(self, "owner_contact", value)

    @_builtins.property
    @pulumi.getter(name="ownerContactId")
    def owner_contact_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        : The ID of an existing owner contact.
        """
        return pulumi.get(self, "owner_contact_id")

    @owner_contact_id.setter
    def owner_contact_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_contact_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        : The Scaleway project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="taskId")
    def task_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the task that created the domain.
        """
        return pulumi.get(self, "task_id")

    @task_id.setter
    def task_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "task_id", value)

    @_builtins.property
    @pulumi.getter(name="technicalContacts")
    def technical_contacts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationTechnicalContactArgs']]]]:
        """
        : Technical contact information.
        """
        return pulumi.get(self, "technical_contacts")

    @technical_contacts.setter
    def technical_contacts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegistrationTechnicalContactArgs']]]]):
        pulumi.set(self, "technical_contacts", value)


@pulumi.type_token("scaleway:domain/registration:Registration")
class Registration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[_builtins.bool]] = None,
                 dnssec: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 duration_in_years: Optional[pulumi.Input[_builtins.int]] = None,
                 owner_contact: Optional[pulumi.Input[Union['RegistrationOwnerContactArgs', 'RegistrationOwnerContactArgsDict']]] = None,
                 owner_contact_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `domain.Registration` resource allows you to purchase and manage domain registrations with Scaleway. Using this resource you can register one or more domains for a specified duration, configure auto-renewal and DNSSEC options, and set contact information. You can supply an owner contact either by providing an existing contact ID or by specifying the complete contact details. The resource automatically returns additional contact information (administrative and technical) as provided by the Scaleway API.

        Refer to the [Domains and DNS documentation](https://www.scaleway.com/en/docs/network/domains-and-dns/) and the [API documentation](https://developers.scaleway.com/) for more details.

        ## Example Usage

        ### Purchase a Single Domain

        The following example purchases a domain with a one-year registration period and specifies the owner contact details. Administrative and technical contacts are returned by the API.

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.domain.Registration("test",
            domain_names=["example.com"],
            duration_in_years=1,
            owner_contact={
                "legal_form": "individual",
                "firstname": "John",
                "lastname": "DOE",
                "email": "john.doe@example.com",
                "phone_number": "+1.23456789",
                "address_line1": "123 Main Street",
                "city": "Paris",
                "zip": "75001",
                "country": "FR",
                "vat_identification_code": "FR12345678901",
                "company_identification_code": "123456789",
            })
        ```

        ### Update Domain Settings

        You can update the resource to enable auto-renewal and DNSSEC:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.domain.Registration("test",
            domain_names=["example.com"],
            duration_in_years=1,
            owner_contact={
                "legal_form": "individual",
                "firstname": "John",
                "lastname": "DOE",
                "email": "john.doe@example.com",
                "phone_number": "+1.23456789",
                "address_line1": "123 Main Street",
                "city": "Paris",
                "zip": "75001",
                "country": "FR",
                "vat_identification_code": "FR12345678901",
                "company_identification_code": "123456789",
            },
            auto_renew=True,
            dnssec=True)
        ```

        ### Purchase Multiple Domains

        The following example registers several domains in one go:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        multi = scaleway.domain.Registration("multi",
            domain_names=[
                "domain1.com",
                "domain2.com",
                "domain3.com",
            ],
            duration_in_years=1,
            owner_contact={
                "legal_form": "individual",
                "firstname": "John",
                "lastname": "DOE",
                "email": "john.doe@example.com",
                "phone_number": "+1.23456789",
                "address_line1": "123 Main Street",
                "city": "Paris",
                "zip": "75001",
                "country": "FR",
                "vat_identification_code": "FR12345678901",
                "company_identification_code": "123456789",
            })
        ```

        ## Contact Blocks

        Each contact block supports the following attributes:

        - `legal_form` (Required, String): Legal form of the contact.
        - `firstname` (Required, String): First name.
        - `lastname` (Required, String): Last name.
        - `company_name` (Optional, String): Company name.
        - `email` (Required, String): Primary email.
        - `phone_number` (Required, String): Primary phone number.
        - `address_line_1` (Required, String): Primary address.
        - `zip` (Required, String): Postal code.
        - `city` (Required, String): City.
        - `country` (Required, String): Country code (ISO format).
        - `vat_identification_code` (Required, String): VAT identification code.
        - `company_identification_code` (Required, String): Company identification code.

        ## Import

        To import an existing domain registration, use:

        bash

        ```sh
        $ pulumi import scaleway:domain/registration:Registration test <project_id>/<task_id>
        ```

        You can use the [scaleway_domain_registration](../data-sources/domain_registration.md) data source to look up the `task_id` and `project_id` by domain name.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] auto_renew: : Enables or disables auto-renewal.
        :param pulumi.Input[_builtins.bool] dnssec: : Enables or disables DNSSEC.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_names: : A list of domain names to be registered.
        :param pulumi.Input[_builtins.int] duration_in_years: : The registration period in years.
        :param pulumi.Input[Union['RegistrationOwnerContactArgs', 'RegistrationOwnerContactArgsDict']] owner_contact: : Details of the owner contact.
        :param pulumi.Input[_builtins.str] owner_contact_id: : The ID of an existing owner contact.
        :param pulumi.Input[_builtins.str] project_id: : The Scaleway project ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegistrationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `domain.Registration` resource allows you to purchase and manage domain registrations with Scaleway. Using this resource you can register one or more domains for a specified duration, configure auto-renewal and DNSSEC options, and set contact information. You can supply an owner contact either by providing an existing contact ID or by specifying the complete contact details. The resource automatically returns additional contact information (administrative and technical) as provided by the Scaleway API.

        Refer to the [Domains and DNS documentation](https://www.scaleway.com/en/docs/network/domains-and-dns/) and the [API documentation](https://developers.scaleway.com/) for more details.

        ## Example Usage

        ### Purchase a Single Domain

        The following example purchases a domain with a one-year registration period and specifies the owner contact details. Administrative and technical contacts are returned by the API.

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.domain.Registration("test",
            domain_names=["example.com"],
            duration_in_years=1,
            owner_contact={
                "legal_form": "individual",
                "firstname": "John",
                "lastname": "DOE",
                "email": "john.doe@example.com",
                "phone_number": "+1.23456789",
                "address_line1": "123 Main Street",
                "city": "Paris",
                "zip": "75001",
                "country": "FR",
                "vat_identification_code": "FR12345678901",
                "company_identification_code": "123456789",
            })
        ```

        ### Update Domain Settings

        You can update the resource to enable auto-renewal and DNSSEC:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        test = scaleway.domain.Registration("test",
            domain_names=["example.com"],
            duration_in_years=1,
            owner_contact={
                "legal_form": "individual",
                "firstname": "John",
                "lastname": "DOE",
                "email": "john.doe@example.com",
                "phone_number": "+1.23456789",
                "address_line1": "123 Main Street",
                "city": "Paris",
                "zip": "75001",
                "country": "FR",
                "vat_identification_code": "FR12345678901",
                "company_identification_code": "123456789",
            },
            auto_renew=True,
            dnssec=True)
        ```

        ### Purchase Multiple Domains

        The following example registers several domains in one go:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        multi = scaleway.domain.Registration("multi",
            domain_names=[
                "domain1.com",
                "domain2.com",
                "domain3.com",
            ],
            duration_in_years=1,
            owner_contact={
                "legal_form": "individual",
                "firstname": "John",
                "lastname": "DOE",
                "email": "john.doe@example.com",
                "phone_number": "+1.23456789",
                "address_line1": "123 Main Street",
                "city": "Paris",
                "zip": "75001",
                "country": "FR",
                "vat_identification_code": "FR12345678901",
                "company_identification_code": "123456789",
            })
        ```

        ## Contact Blocks

        Each contact block supports the following attributes:

        - `legal_form` (Required, String): Legal form of the contact.
        - `firstname` (Required, String): First name.
        - `lastname` (Required, String): Last name.
        - `company_name` (Optional, String): Company name.
        - `email` (Required, String): Primary email.
        - `phone_number` (Required, String): Primary phone number.
        - `address_line_1` (Required, String): Primary address.
        - `zip` (Required, String): Postal code.
        - `city` (Required, String): City.
        - `country` (Required, String): Country code (ISO format).
        - `vat_identification_code` (Required, String): VAT identification code.
        - `company_identification_code` (Required, String): Company identification code.

        ## Import

        To import an existing domain registration, use:

        bash

        ```sh
        $ pulumi import scaleway:domain/registration:Registration test <project_id>/<task_id>
        ```

        You can use the [scaleway_domain_registration](../data-sources/domain_registration.md) data source to look up the `task_id` and `project_id` by domain name.

        :param str resource_name: The name of the resource.
        :param RegistrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegistrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_renew: Optional[pulumi.Input[_builtins.bool]] = None,
                 dnssec: Optional[pulumi.Input[_builtins.bool]] = None,
                 domain_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 duration_in_years: Optional[pulumi.Input[_builtins.int]] = None,
                 owner_contact: Optional[pulumi.Input[Union['RegistrationOwnerContactArgs', 'RegistrationOwnerContactArgsDict']]] = None,
                 owner_contact_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegistrationArgs.__new__(RegistrationArgs)

            __props__.__dict__["auto_renew"] = auto_renew
            __props__.__dict__["dnssec"] = dnssec
            if domain_names is None and not opts.urn:
                raise TypeError("Missing required property 'domain_names'")
            __props__.__dict__["domain_names"] = domain_names
            __props__.__dict__["duration_in_years"] = duration_in_years
            __props__.__dict__["owner_contact"] = owner_contact
            __props__.__dict__["owner_contact_id"] = owner_contact_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["administrative_contacts"] = None
            __props__.__dict__["ds_records"] = None
            __props__.__dict__["task_id"] = None
            __props__.__dict__["technical_contacts"] = None
        super(Registration, __self__).__init__(
            'scaleway:domain/registration:Registration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            administrative_contacts: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RegistrationAdministrativeContactArgs', 'RegistrationAdministrativeContactArgsDict']]]]] = None,
            auto_renew: Optional[pulumi.Input[_builtins.bool]] = None,
            dnssec: Optional[pulumi.Input[_builtins.bool]] = None,
            domain_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            ds_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RegistrationDsRecordArgs', 'RegistrationDsRecordArgsDict']]]]] = None,
            duration_in_years: Optional[pulumi.Input[_builtins.int]] = None,
            owner_contact: Optional[pulumi.Input[Union['RegistrationOwnerContactArgs', 'RegistrationOwnerContactArgsDict']]] = None,
            owner_contact_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            task_id: Optional[pulumi.Input[_builtins.str]] = None,
            technical_contacts: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RegistrationTechnicalContactArgs', 'RegistrationTechnicalContactArgsDict']]]]] = None) -> 'Registration':
        """
        Get an existing Registration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RegistrationAdministrativeContactArgs', 'RegistrationAdministrativeContactArgsDict']]]] administrative_contacts: : Administrative contact information.
        :param pulumi.Input[_builtins.bool] auto_renew: : Enables or disables auto-renewal.
        :param pulumi.Input[_builtins.bool] dnssec: : Enables or disables DNSSEC.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] domain_names: : A list of domain names to be registered.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RegistrationDsRecordArgs', 'RegistrationDsRecordArgsDict']]]] ds_records: DNSSEC DS record configuration.
        :param pulumi.Input[_builtins.int] duration_in_years: : The registration period in years.
        :param pulumi.Input[Union['RegistrationOwnerContactArgs', 'RegistrationOwnerContactArgsDict']] owner_contact: : Details of the owner contact.
        :param pulumi.Input[_builtins.str] owner_contact_id: : The ID of an existing owner contact.
        :param pulumi.Input[_builtins.str] project_id: : The Scaleway project ID.
        :param pulumi.Input[_builtins.str] task_id: ID of the task that created the domain.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RegistrationTechnicalContactArgs', 'RegistrationTechnicalContactArgsDict']]]] technical_contacts: : Technical contact information.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegistrationState.__new__(_RegistrationState)

        __props__.__dict__["administrative_contacts"] = administrative_contacts
        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["dnssec"] = dnssec
        __props__.__dict__["domain_names"] = domain_names
        __props__.__dict__["ds_records"] = ds_records
        __props__.__dict__["duration_in_years"] = duration_in_years
        __props__.__dict__["owner_contact"] = owner_contact
        __props__.__dict__["owner_contact_id"] = owner_contact_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["task_id"] = task_id
        __props__.__dict__["technical_contacts"] = technical_contacts
        return Registration(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="administrativeContacts")
    def administrative_contacts(self) -> pulumi.Output[Sequence['outputs.RegistrationAdministrativeContact']]:
        """
        : Administrative contact information.
        """
        return pulumi.get(self, "administrative_contacts")

    @_builtins.property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        : Enables or disables auto-renewal.
        """
        return pulumi.get(self, "auto_renew")

    @_builtins.property
    @pulumi.getter
    def dnssec(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        : Enables or disables DNSSEC.
        """
        return pulumi.get(self, "dnssec")

    @_builtins.property
    @pulumi.getter(name="domainNames")
    def domain_names(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        : A list of domain names to be registered.
        """
        return pulumi.get(self, "domain_names")

    @_builtins.property
    @pulumi.getter(name="dsRecords")
    def ds_records(self) -> pulumi.Output[Sequence['outputs.RegistrationDsRecord']]:
        """
        DNSSEC DS record configuration.
        """
        return pulumi.get(self, "ds_records")

    @_builtins.property
    @pulumi.getter(name="durationInYears")
    def duration_in_years(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        : The registration period in years.
        """
        return pulumi.get(self, "duration_in_years")

    @_builtins.property
    @pulumi.getter(name="ownerContact")
    def owner_contact(self) -> pulumi.Output['outputs.RegistrationOwnerContact']:
        """
        : Details of the owner contact.
        """
        return pulumi.get(self, "owner_contact")

    @_builtins.property
    @pulumi.getter(name="ownerContactId")
    def owner_contact_id(self) -> pulumi.Output[_builtins.str]:
        """
        : The ID of an existing owner contact.
        """
        return pulumi.get(self, "owner_contact_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        : The Scaleway project ID.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="taskId")
    def task_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the task that created the domain.
        """
        return pulumi.get(self, "task_id")

    @_builtins.property
    @pulumi.getter(name="technicalContacts")
    def technical_contacts(self) -> pulumi.Output[Sequence['outputs.RegistrationTechnicalContact']]:
        """
        : Technical contact information.
        """
        return pulumi.get(self, "technical_contacts")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['FlexibleIpMacAddressArgs', 'FlexibleIpMacAddress']

@pulumi.input_type
class FlexibleIpMacAddressArgs:
    def __init__(__self__, *,
                 flexible_ip_id: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 flexible_ip_ids_to_duplicates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FlexibleIpMacAddress resource.
        :param pulumi.Input[_builtins.str] flexible_ip_id: The ID of the flexible IP for which to generate a virtual MAC.
        :param pulumi.Input[_builtins.str] type: The type of the virtual MAC.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] flexible_ip_ids_to_duplicates: The IDs of the flexible IPs on which to duplicate the virtual MAC.
               > **Important:** The flexible IPs need to be attached to the same server for the operation to work.
        :param pulumi.Input[_builtins.str] zone: The zone of the Virtual Mac Address.
        """
        pulumi.set(__self__, "flexible_ip_id", flexible_ip_id)
        pulumi.set(__self__, "type", type)
        if flexible_ip_ids_to_duplicates is not None:
            pulumi.set(__self__, "flexible_ip_ids_to_duplicates", flexible_ip_ids_to_duplicates)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="flexibleIpId")
    def flexible_ip_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the flexible IP for which to generate a virtual MAC.
        """
        return pulumi.get(self, "flexible_ip_id")

    @flexible_ip_id.setter
    def flexible_ip_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "flexible_ip_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the virtual MAC.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="flexibleIpIdsToDuplicates")
    def flexible_ip_ids_to_duplicates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of the flexible IPs on which to duplicate the virtual MAC.
        > **Important:** The flexible IPs need to be attached to the same server for the operation to work.
        """
        return pulumi.get(self, "flexible_ip_ids_to_duplicates")

    @flexible_ip_ids_to_duplicates.setter
    def flexible_ip_ids_to_duplicates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "flexible_ip_ids_to_duplicates", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone of the Virtual Mac Address.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _FlexibleIpMacAddressState:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 flexible_ip_id: Optional[pulumi.Input[_builtins.str]] = None,
                 flexible_ip_ids_to_duplicates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FlexibleIpMacAddress resources.
        :param pulumi.Input[_builtins.str] address: The Virtual MAC address.
        :param pulumi.Input[_builtins.str] created_at: The date at which the Virtual Mac Address was created (RFC 3339 format).
        :param pulumi.Input[_builtins.str] flexible_ip_id: The ID of the flexible IP for which to generate a virtual MAC.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] flexible_ip_ids_to_duplicates: The IDs of the flexible IPs on which to duplicate the virtual MAC.
               > **Important:** The flexible IPs need to be attached to the same server for the operation to work.
        :param pulumi.Input[_builtins.str] status: The Virtual MAC status.
        :param pulumi.Input[_builtins.str] type: The type of the virtual MAC.
        :param pulumi.Input[_builtins.str] updated_at: The date at which the Virtual Mac Address was last updated (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: The zone of the Virtual Mac Address.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if flexible_ip_id is not None:
            pulumi.set(__self__, "flexible_ip_id", flexible_ip_id)
        if flexible_ip_ids_to_duplicates is not None:
            pulumi.set(__self__, "flexible_ip_ids_to_duplicates", flexible_ip_ids_to_duplicates)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Virtual MAC address.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date at which the Virtual Mac Address was created (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="flexibleIpId")
    def flexible_ip_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the flexible IP for which to generate a virtual MAC.
        """
        return pulumi.get(self, "flexible_ip_id")

    @flexible_ip_id.setter
    def flexible_ip_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "flexible_ip_id", value)

    @_builtins.property
    @pulumi.getter(name="flexibleIpIdsToDuplicates")
    def flexible_ip_ids_to_duplicates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of the flexible IPs on which to duplicate the virtual MAC.
        > **Important:** The flexible IPs need to be attached to the same server for the operation to work.
        """
        return pulumi.get(self, "flexible_ip_ids_to_duplicates")

    @flexible_ip_ids_to_duplicates.setter
    def flexible_ip_ids_to_duplicates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "flexible_ip_ids_to_duplicates", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Virtual MAC status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the virtual MAC.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date at which the Virtual Mac Address was last updated (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone of the Virtual Mac Address.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


warnings.warn("""scaleway.index/flexibleipmacaddress.FlexibleIpMacAddress has been deprecated in favor of scaleway.elasticmetal/ipmacaddress.IpMacAddress""", DeprecationWarning)


@pulumi.type_token("scaleway:index/flexibleIpMacAddress:FlexibleIpMacAddress")
class FlexibleIpMacAddress(pulumi.CustomResource):
    warnings.warn("""scaleway.index/flexibleipmacaddress.FlexibleIpMacAddress has been deprecated in favor of scaleway.elasticmetal/ipmacaddress.IpMacAddress""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 flexible_ip_id: Optional[pulumi.Input[_builtins.str]] = None,
                 flexible_ip_ids_to_duplicates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Flexible IP Mac Addresses.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/elastic-metal-flexible-ip/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.elasticmetal.Ip("main")
        main_ip_mac_address = scaleway.elasticmetal.IpMacAddress("main",
            flexible_ip_id=main.id,
            type="kvm")
        ```

        ### Duplicate on many other flexible IPs

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        my_offer = scaleway.elasticmetal.get_offer(name="EM-B112X-SSD")
        base = scaleway.elasticmetal.Server("base",
            name="TestAccScalewayBaremetalServer_WithoutInstallConfig",
            offer=my_offer.offer_id,
            install_config_afterward=True)
        ip01 = scaleway.elasticmetal.Ip("ip01", server_id=base.id)
        ip02 = scaleway.elasticmetal.Ip("ip02", server_id=base.id)
        ip03 = scaleway.elasticmetal.Ip("ip03", server_id=base.id)
        main = scaleway.elasticmetal.IpMacAddress("main",
            flexible_ip_id=ip01.id,
            type="kvm",
            flexible_ip_ids_to_duplicates=[
                ip02.id,
                ip03.id,
            ])
        ```

        ## Import

        Flexible IP Mac Addresses can be imported using the `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/flexibleIpMacAddress:FlexibleIpMacAddress main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] flexible_ip_id: The ID of the flexible IP for which to generate a virtual MAC.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] flexible_ip_ids_to_duplicates: The IDs of the flexible IPs on which to duplicate the virtual MAC.
               > **Important:** The flexible IPs need to be attached to the same server for the operation to work.
        :param pulumi.Input[_builtins.str] type: The type of the virtual MAC.
        :param pulumi.Input[_builtins.str] zone: The zone of the Virtual Mac Address.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FlexibleIpMacAddressArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Flexible IP Mac Addresses.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/elastic-metal-flexible-ip/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.elasticmetal.Ip("main")
        main_ip_mac_address = scaleway.elasticmetal.IpMacAddress("main",
            flexible_ip_id=main.id,
            type="kvm")
        ```

        ### Duplicate on many other flexible IPs

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        my_offer = scaleway.elasticmetal.get_offer(name="EM-B112X-SSD")
        base = scaleway.elasticmetal.Server("base",
            name="TestAccScalewayBaremetalServer_WithoutInstallConfig",
            offer=my_offer.offer_id,
            install_config_afterward=True)
        ip01 = scaleway.elasticmetal.Ip("ip01", server_id=base.id)
        ip02 = scaleway.elasticmetal.Ip("ip02", server_id=base.id)
        ip03 = scaleway.elasticmetal.Ip("ip03", server_id=base.id)
        main = scaleway.elasticmetal.IpMacAddress("main",
            flexible_ip_id=ip01.id,
            type="kvm",
            flexible_ip_ids_to_duplicates=[
                ip02.id,
                ip03.id,
            ])
        ```

        ## Import

        Flexible IP Mac Addresses can be imported using the `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/flexibleIpMacAddress:FlexibleIpMacAddress main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param FlexibleIpMacAddressArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FlexibleIpMacAddressArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 flexible_ip_id: Optional[pulumi.Input[_builtins.str]] = None,
                 flexible_ip_ids_to_duplicates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""FlexibleIpMacAddress is deprecated: scaleway.index/flexibleipmacaddress.FlexibleIpMacAddress has been deprecated in favor of scaleway.elasticmetal/ipmacaddress.IpMacAddress""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FlexibleIpMacAddressArgs.__new__(FlexibleIpMacAddressArgs)

            if flexible_ip_id is None and not opts.urn:
                raise TypeError("Missing required property 'flexible_ip_id'")
            __props__.__dict__["flexible_ip_id"] = flexible_ip_id
            __props__.__dict__["flexible_ip_ids_to_duplicates"] = flexible_ip_ids_to_duplicates
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["zone"] = zone
            __props__.__dict__["address"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(FlexibleIpMacAddress, __self__).__init__(
            'scaleway:index/flexibleIpMacAddress:FlexibleIpMacAddress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            flexible_ip_id: Optional[pulumi.Input[_builtins.str]] = None,
            flexible_ip_ids_to_duplicates: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'FlexibleIpMacAddress':
        """
        Get an existing FlexibleIpMacAddress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address: The Virtual MAC address.
        :param pulumi.Input[_builtins.str] created_at: The date at which the Virtual Mac Address was created (RFC 3339 format).
        :param pulumi.Input[_builtins.str] flexible_ip_id: The ID of the flexible IP for which to generate a virtual MAC.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] flexible_ip_ids_to_duplicates: The IDs of the flexible IPs on which to duplicate the virtual MAC.
               > **Important:** The flexible IPs need to be attached to the same server for the operation to work.
        :param pulumi.Input[_builtins.str] status: The Virtual MAC status.
        :param pulumi.Input[_builtins.str] type: The type of the virtual MAC.
        :param pulumi.Input[_builtins.str] updated_at: The date at which the Virtual Mac Address was last updated (RFC 3339 format).
        :param pulumi.Input[_builtins.str] zone: The zone of the Virtual Mac Address.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FlexibleIpMacAddressState.__new__(_FlexibleIpMacAddressState)

        __props__.__dict__["address"] = address
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["flexible_ip_id"] = flexible_ip_id
        __props__.__dict__["flexible_ip_ids_to_duplicates"] = flexible_ip_ids_to_duplicates
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["zone"] = zone
        return FlexibleIpMacAddress(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def address(self) -> pulumi.Output[_builtins.str]:
        """
        The Virtual MAC address.
        """
        return pulumi.get(self, "address")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date at which the Virtual Mac Address was created (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="flexibleIpId")
    def flexible_ip_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the flexible IP for which to generate a virtual MAC.
        """
        return pulumi.get(self, "flexible_ip_id")

    @_builtins.property
    @pulumi.getter(name="flexibleIpIdsToDuplicates")
    def flexible_ip_ids_to_duplicates(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The IDs of the flexible IPs on which to duplicate the virtual MAC.
        > **Important:** The flexible IPs need to be attached to the same server for the operation to work.
        """
        return pulumi.get(self, "flexible_ip_ids_to_duplicates")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The Virtual MAC status.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the virtual MAC.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date at which the Virtual Mac Address was last updated (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The zone of the Virtual Mac Address.
        """
        return pulumi.get(self, "zone")

